@@ -23,18 +23,12 @@ logger.setLevel(logging.WARNING)
 # 주식을 통한 기대수익률 - 금리가 3%일 경우 두배인 6% 정도로 잡는다.
 EXPECT_EARN = 0.04
 
-corps_eval = CorpsEval(code='005930')
-c101 = mongo.C101(code='005930')
-c103 = mongo.C103(code='005930')
-c104 = mongo.C104(code='005930')
-c106 = mongo.C106(code='005930')
-
 
 def red(code: str) -> dict:
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
-        c101.chg_code(code)
-        c103.chg_code(code)
+        corps_eval = CorpsEval(code)
+        c101 = mongo.C101(code)
+        c103 = mongo.C103(code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
@@ -80,9 +74,9 @@ def red(code: str) -> dict:
 
 def mil(code: str) -> dict:
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
-        c103.chg_code(code)
-        c104.chg_code(code)
+        corps_eval = CorpsEval(code)
+        c103 = mongo.C103(code)
+        c104 = mongo.C104(code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
@@ -139,10 +133,10 @@ def blue(code: str) -> dict:
     <영업이익률>
     영업이익률은 기업의 경쟁력척도로 경쟁사에 비해 높으면 경제적해자를 갖춘셈
     """
+
     if utils.is_6digit(code):
-        corps_eval.chg_code(code)
-        c103.chg_code(code)
-        c104.chg_code(code)
+        corps_eval = CorpsEval(code)
+        c104 = mongo.C104(code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
@@ -190,8 +184,8 @@ def growth(code: str) -> dict:
     영업이익률은 기업의 경쟁력척도로 경쟁사에 비해 높으면 경제적해자를 갖춘셈
     """
     if utils.is_6digit(code):
-        c104.chg_code(code)
-        c106.chg_code(code)
+        c104 = mongo.C104(code)
+        c106 = mongo.C106(code)
     else:
         raise ValueError(f'Invalid code: {code}')
 
